@@ -2,7 +2,7 @@
 # Copyright (c) 2019-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import structlog
-from typing import Optional, Dict
+from typing import Optional, Dict, Mapping
 import json as _json
 
 from ..ctxvars import tries, proxy, user_agent
@@ -14,8 +14,16 @@ class Response:
 
   .. py:attribute:: body
      :type: bytes
+
+  .. py:attribute:: headers
+     :type: Mapping[str, str]
   '''
-  def __init__(self, body):
+  def __init__(
+    self,
+    headers: Mapping[str, str],
+    body: bytes,
+  ) -> None:
+    self.headers = headers
     self.body = body
 
   def json(self):
@@ -31,6 +39,11 @@ class BaseSession:
   ) -> None:
     pass
 
+  async def head(self, *args, **kwargs):
+    '''Shortcut for ``HEAD`` request.'''
+    return await self.request(
+      method='HEAD', *args, **kwargs)
+
   async def get(self, *args, **kwargs):
     '''Shortcut for ``GET`` request.'''
     return await self.request(
@@ -45,6 +58,7 @@ class BaseSession:
     self, url: str, *,
     method: str,
     headers: Dict[str, str] = {},
+    follow_redirects: bool = True,
     params = (),
     json = None,
   ) -> Response:
@@ -62,6 +76,7 @@ class BaseSession:
           method = method,
           headers = headers,
           params = params,
+          follow_redirects = follow_redirects,
           json = json,
           proxy = p or None,
         )
@@ -80,6 +95,7 @@ class BaseSession:
     method: str,
     proxy: Optional[str] = None,
     headers: Dict[str, str] = {},
+    follow_redirects: bool = True,
     params = (),
     json = None,
   ) -> Response:
